@@ -291,12 +291,13 @@ class Field(models.Model):
             kwargs.update({"widget": forms.Select(), "choices": choices})
         elif self.field_type == Field.CHECKBOX_FIELD:
             field_class = forms.MultipleChoiceField
-            kwargs.update({"widget": forms.CheckboxInput(), "choices": choices})
+            kwargs.update({"widget": forms.CheckboxSelectMultiple(), "choices": choices})
         elif self.field_type == Field.BOOLEAN_FIELD:
             field_class = forms.BooleanField
         elif self.field_type == Field.MEDIA_FIELD:
             field_class = forms.FileField
         
+        print field_class, kwargs
         return field_class(**kwargs)
 
 
@@ -319,12 +320,12 @@ class SurveyResult(models.Model):
 
 
 class FieldResult(models.Model):
-    survey = models.ForeignKey(Survey, related_name="results") # Denorm
-    page = models.ForeignKey(Page, related_name="results") # Denorm
+    survey = models.ForeignKey(Survey, related_name="results")  # Denorm
+    page = models.ForeignKey(Page, related_name="results")  # Denorm
     result = models.ForeignKey(SurveyResult, related_name="results")
     question = models.ForeignKey(Field, related_name="results")
     upload = models.FileField(upload_to="formly/", blank=True)
-    answer = JSONField(blank=True) # @@@ I think this should be something different than a string
+    answer = JSONField(blank=True)  # @@@ I think this should be something different than a string
     
     def answer_value(self):
         if self.answer:
